/**
 * 
 */
package org.freedesktop.minidbus;

import java.lang.ref.WeakReference;

/**
 * Callbacks are called on incoming messages within the context
 * of the DBusReceiving thread.  These _MUST_ only do light processing
 * and you have to be careful about blocking the receive thread, which
 * can lead to deadlocks.
 * 
 * Simple usage of the MessageCallback could be to simply queue a message
 * in an event loop.
 * 
 * @author Ed Wei
 */
public abstract class MessageCallback<Context> {
    
    private WeakReference<Context> context;
    boolean singleShot;
    
    public MessageCallback(Context t)
    {
    	context = new WeakReference<Context>(t);
    	singleShot = true;
    }
    
    public MessageCallback(Context t, boolean singleShot)
    {
        context = new WeakReference<Context>(t);
        this.singleShot = singleShot;
    }
    
    public Context getContext()
    {
        Context t = context.get();
        return t;
    }
    
    public abstract void callback(final Object context, final Message reply);

	public boolean isSingleShot() {
		return singleShot;
	}
}
